@@ -68,7 +68,7 @@ class Client():
 
         hostname = socket.gethostname()
         ip_addr  = socket.gethostbyname(hostname)
-        current_time = str(dt.datetime.now()))
+        current_time = str(dt.datetime.now())
 
         graphql.execute(
             CREATE_NEW_USER_MUTATION(hostname,ip_addr,current_time)
